@@ -175,7 +175,8 @@ class BoardStatus(TimeStampedModel):
     display_on_board = models.BooleanField()
     inactive = models.BooleanField()
     closed_status = models.BooleanField()
-    board = models.ForeignKey('ConnectWiseBoard', on_delete=models.CASCADE)
+    board = models.ForeignKey(
+        'ConnectWiseBoard', blank=True, null=True, on_delete=models.SET_NULL)
     # Letting escalation_status allow blank/null rather than possibly having
     # and incorrect default value in some edge case
     escalation_status = models.CharField(
@@ -738,15 +739,16 @@ class ScheduleEntry(models.Model):
         'Ticket',
         blank=True,
         null=True,
-        on_delete=models.CASCADE
+        on_delete=models.SET_NULL
     )
     activity_object = models.ForeignKey(
         'Activity',
         blank=True,
         null=True,
-        on_delete=models.CASCADE
+        on_delete=models.SET_NULL
     )
-    member = models.ForeignKey('Member', on_delete=models.CASCADE)
+    member = models.ForeignKey(
+        'Member', blank=True, null=True, on_delete=models.SET_NULL)
     where = models.ForeignKey(
         'Location',
         blank=True,
@@ -832,7 +834,7 @@ class TimeEntry(models.Model):
     charge_to_id = models.ForeignKey(
         'Ticket', blank=True, null=True, on_delete=models.CASCADE)
     company = models.ForeignKey(
-        'Company', blank=True, null=True, on_delete=models.CASCADE)
+        'Company', blank=True, null=True, on_delete=models.SET_NULL)
     member = models.ForeignKey(
         'Member', blank=True, null=True, on_delete=models.CASCADE)
     work_type = models.ForeignKey(
@@ -1040,12 +1042,13 @@ class Project(TimeStampedModel):
         blank=True, null=True, decimal_places=2, max_digits=3)
     scheduled_start = models.DateField(blank=True, null=True)
     scheduled_end = models.DateField(blank=True, null=True)
+    description = models.TextField(blank=True, null=True)
 
     board = models.ForeignKey(
         'ConnectWiseBoard',
         blank=True,
         null=True,
-        on_delete=models.CASCADE
+        on_delete=models.SET_NULL
     )
     company = models.ForeignKey(
         'Company', on_delete=models.SET_NULL, blank=True, null=True
@@ -1290,6 +1293,12 @@ class Ticket(TimeStampedModel):
             [type[0] for type in SLA_STAGE]
         )
     )
+    TICKET = 'Ticket'
+    PHASE = 'Phase'
+    PREDECESSOR_TYPES = (
+        (TICKET, 'Ticket'),
+        (PHASE, 'Phase')
+    )
 
     actual_hours = models.DecimalField(
         blank=True, null=True, decimal_places=2, max_digits=9)
@@ -1337,8 +1346,19 @@ class Ticket(TimeStampedModel):
     automatic_email_contact_flag = models.BooleanField(default=False)
     automatic_email_resource_flag = models.BooleanField(default=False)
 
+    predecessor_type = models.CharField(blank=True, null=True, max_length=10,
+                                        choices=PREDECESSOR_TYPES)
+    lag_days = models.IntegerField(blank=True, null=True)
+    lag_non_working_days_flag = models.BooleanField(default=False)
+
+    ticket_predecessor = models.ForeignKey(
+        'self', blank=True, null=True, on_delete=models.SET_NULL
+    )
+    phase_predecessor = models.ForeignKey(
+        'ProjectPhase', blank=True, null=True, on_delete=models.SET_NULL
+    )
     board = models.ForeignKey(
-        'ConnectwiseBoard', blank=True, null=True, on_delete=models.CASCADE)
+        'ConnectwiseBoard', blank=True, null=True, on_delete=models.SET_NULL)
     company = models.ForeignKey(
         'Company', blank=True, null=True, related_name='company_tickets',
         on_delete=models.SET_NULL)
@@ -1354,7 +1374,7 @@ class Ticket(TimeStampedModel):
         'TicketPriority', blank=True, null=True, on_delete=models.SET_NULL)
     project = models.ForeignKey(
         'Project', blank=True, null=True, related_name='project_tickets',
-        on_delete=models.CASCADE)
+        on_delete=models.SET_NULL)
     phase = models.ForeignKey(
         'ProjectPhase', blank=True, null=True, related_name='phase_tickets',
         on_delete=models.SET_NULL)
@@ -1705,7 +1725,7 @@ class Activity(TimeStampedModel):
     type = models.ForeignKey(
         'ActivityType', blank=True, null=True, on_delete=models.SET_NULL)
     company = models.ForeignKey(
-        'Company', blank=True, null=True, on_delete=models.CASCADE)
+        'Company', blank=True, null=True, on_delete=models.SET_NULL)
     agreement = models.ForeignKey(
         'Agreement', blank=True, null=True, on_delete=models.SET_NULL)
     tracker = FieldTracker()
