@@ -982,8 +982,8 @@ API_SERVICE_TICKET = {
     'predecessorType': None,
     'predecessorId': None,
     'predecessorClosedFlag': None,
-    'lagDays': None,
-    'lagNonworkingDaysFlag': None,
+    'lagDays': 0,
+    'lagNonworkingDaysFlag': False,
     'estimatedStartDate': None,
     'duration': None,
     'businessUnitId': 10,
